SystemOrganization addCategory: #'System-Applications'!

Object subclass: #AppRegistry
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Applications'!

AppRegistry class
	instanceVariableNames: 'registeredClasses default'!

!AppRegistry commentStamp: 'ads 4/2/2003 15:30' prior: 0!
AppRegistry is a simple little class, not much more than a wrapper around a collection. It's intended to help break dependencies between packages. For example, if you'd like to be able to send e-mail, you could use the bare-bones MailComposition class, or you could use the full-blown Celeste e-mail client. Instead of choosing one or the other, you can call "MailSender default" (where MailSender is a subclass of AppRegistry), and thus avoid creating a hard-coded dependency on either of the two mail senders.

This will only really be useful, of course, for applications that have a very simple, general, well-defined interface. Most of the time, you're probably better off just marking your package as being dependent on a specific other package, and avoiding the hassle of this whole AppRegistry thing. But for simple things like e-mail senders or web browsers, it might be useful.
!

AppRegistry class
	instanceVariableNames: 'registeredClasses default'!

!AppRegistry class methodsFor: 'as yet unclassified' stamp: 'ads 3/29/2003 13:36'!
appName
	"Defaults to the class name, which is probably good enough, but you could override this in subclasses if you want to."
	^ self name! !

!AppRegistry class methodsFor: 'as yet unclassified' stamp: 'alain.plantec 2/8/2009 21:37'!
askForDefault
	"self askForDefault"
	self registeredClasses isEmpty ifTrue:
		[self inform: 'There are no ', self appName, ' applications registered.'.
		^ default := nil].
	self registeredClasses size = 1 ifTrue:
		[^ default := self registeredClasses anyOne].
	
	default := UIManager default 
		chooseFrom: (self registeredClasses collect: [:c | c name]) 
		values: self registeredClasses 
		title: ('Which ' , self appName, ' would you prefer?') translated.
	default ifNil: [default := self registeredClasses first].
	^default.! !

!AppRegistry class methodsFor: 'as yet unclassified' stamp: 'ads 3/29/2003 13:11'!
default
	^ default ifNil: [self askForDefault]! !

!AppRegistry class methodsFor: 'as yet unclassified' stamp: 'nk 3/9/2004 12:33'!
default: aClassOrNil
	"Sets my default to aClassOrNil. 
	Answers the old default."
	| oldDefault |
	oldDefault := default.
	aClassOrNil ifNotNil: [ self register: aClassOrNil ].
	default := aClassOrNil.
	^ oldDefault! !

!AppRegistry class methodsFor: 'as yet unclassified' stamp: 'nk 3/9/2004 12:35'!
defaultOrNil
	^ default! !

!AppRegistry class methodsFor: 'as yet unclassified' stamp: 'ads 4/2/2003 15:25'!
register: aProviderClass
	(self registeredClasses includes: aProviderClass) ifFalse:
		[default := nil.  "so it'll ask for a new default, since if you're registering a new app you probably want to use it"
		self registeredClasses add: aProviderClass].! !

!AppRegistry class methodsFor: 'as yet unclassified' stamp: 'ads 3/29/2003 13:01'!
registeredClasses
	^ registeredClasses ifNil: [registeredClasses := OrderedCollection new]! !

!AppRegistry class methodsFor: 'as yet unclassified' stamp: 'ar 9/27/2005 21:48'!
removeObsolete
	"AppRegistry removeObsoleteClasses"
	self registeredClasses copy do:[:cls| 
		(cls class isObsolete or:[cls isBehavior and:[cls isObsolete]]) 
			ifTrue:[self unregister: cls]].
	self subclasses do:[:cls| cls removeObsolete].! !

!AppRegistry class methodsFor: 'as yet unclassified' stamp: 'ads 3/29/2003 13:03'!
unregister: aProviderClass
	(default = aProviderClass) ifTrue: [default := nil].
	self registeredClasses remove: aProviderClass ifAbsent: [].! !

!AppRegistry methodsFor: 'notes' stamp: 'ads 4/2/2003 15:04'!
seeClassSide
	"All the code for AppRegistry is on the class side."! !

AppRegistry subclass: #MailSender
	instanceVariableNames: ''
	classVariableNames: 'SmtpServer UserName'
	poolDictionaries: ''
	category: 'System-Applications'!

!MailSender class methodsFor: 'testing' stamp: 'dvf 5/11/2002 01:31'!
isSmtpServerSet
	^ SmtpServer notNil and: [SmtpServer notEmpty]
! !

!MailSender class methodsFor: 'communication' stamp: 'ads 5/11/2003 21:11'!
sendMessage: aMailMessage

	self default ifNotNil: [self default sendMailMessage: aMailMessage]! !

!MailSender class methodsFor: 'settings' stamp: 'rbb 3/1/2005 10:59'!
setSmtpServer
	"Set the SMTP server used to send outgoing messages via"
	SmtpServer ifNil: [SmtpServer := ''].
	SmtpServer := UIManager default
		request: 'What is your mail server for outgoing mail?'
		initialAnswer: SmtpServer.
! !

!MailSender class methodsFor: 'settings' stamp: 'rbb 3/1/2005 11:00'!
setUserName
	"Change the user's email name for use in composing messages."

	(UserName isNil) ifTrue: [UserName := ''].
	UserName := UIManager default
		request: 'What is your email address?\(This is the address other people will reply to you)' withCRs
		initialAnswer: UserName.
	UserName ifNotNil: [UserName := UserName]! !

!MailSender class methodsFor: 'accessing' stamp: 'dvf 5/11/2002 01:29'!
smtpServer
	"Answer the server for sending email"

	self isSmtpServerSet
		ifFalse: [self setSmtpServer].
	SmtpServer isEmpty ifTrue: [
		self error: 'no SMTP server specified' ].

	^SmtpServer! !

!MailSender class methodsFor: 'accessing' stamp: 'dvf 5/11/2002 00:49'!
userName
	"Answer the user name to be used in composing messages."

	(UserName isNil or: [UserName isEmpty])
		ifTrue: [self setUserName].

	UserName isEmpty ifTrue: [ self error: 'no user name specified' ].

	^UserName! !

AppRegistry subclass: #MorphicTextEditor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Applications'!

AppRegistry subclass: #PrettyPrinting
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Applications'!

!PrettyPrinting class methodsFor: 'class initialization' stamp: 'damiencassou 7/30/2009 10:55'!
initialize
	"I'm a registry as well as a default provider"
	self register: self! !

!PrettyPrinting class methodsFor: 'pretty printing' stamp: 'damiencassou 7/30/2009 10:59'!
prettyPrinterClassFor: aBehavior
	|defaultPrinter|
	defaultPrinter := self default.
	^ (defaultPrinter isNil or: [defaultPrinter = self])
		ifTrue: [aBehavior compilerClass]
		ifFalse: [self default prettyPrinterClassFor: aBehavior]! !

AppRegistry subclass: #SoundService
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Applications'!

!SoundService commentStamp: 'gk 2/24/2004 23:14' prior: 0!
This is the AppRegistry class for the sound system.

A sound system offers a small protocol for playing sounds and making beeps and works like a facade towards the rest of Squeak. A sound system is registered in this registry and can be accessed by "SoundService default". This way we decouple the sound system from the rest of Squeak and make it pluggable. It also is a perfect spot to check for the Preference class>>soundsEnabled.!

AppRegistry subclass: #ToolSet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Applications'!

!ToolSet commentStamp: 'ar 7/15/2005 17:58' prior: 0!
ToolSet defines an interface that clients can use to request programmer facilities such as browsers, inspectors, debuggers, message sets etc.!

!ToolSet class methodsFor: 'accessing' stamp: 'ar 7/17/2005 10:47'!
askForDefault
	"Ask for the default implementor"
	self registeredClasses isEmpty 
		ifTrue:[^ default := nil].
	self registeredClasses size = 1 
		ifTrue:[^ default := self registeredClasses anyOne].
	default := UIManager default 
		chooseFrom: (self registeredClasses collect:[:each| each name printString])
		values: self registeredClasses
		title: 'Which ', self appName, ' would you prefer?'.
	^default.! !

!ToolSet class methodsFor: 'inspecting' stamp: 'ar 7/17/2005 10:54'!
basicInspect: anObject
	"Open an inspector on the given object. The tool set must know which inspector type to use for which object - the object cannot possibly know what kind of inspectors the toolset provides."
	self default ifNil:[^self inform: 'Cannot inspect -- no Inspector present'].
	^self default basicInspect: anObject! !

!ToolSet class methodsFor: 'browsing' stamp: 'ar 7/17/2005 10:54'!
browse: aClass selector: aSelector
	"Open a browser"
	self default ifNil:[^self inform: 'Cannot open Browser'].
	^self default browse: aClass selector: aSelector! !

!ToolSet class methodsFor: 'browsing' stamp: 'ar 7/17/2005 10:54'!
browseChangeSetsWithClass: aClass selector: aSelector
	"Browse all the change sets with the given class/selector"
	self default ifNil:[^self inform: 'No ChangeSorter present'].
	^self default browseChangeSetsWithClass: aClass selector: aSelector! !

!ToolSet class methodsFor: 'browsing' stamp: 'ar 7/17/2005 11:14'!
browseHierarchy: aClass selector: aSelector
	"Open a browser"
	self default ifNil:[^self inform: 'No browser present'].
	^self default browseHierarchy: aClass selector: aSelector! !

!ToolSet class methodsFor: 'browsing' stamp: 'davidroethlisberger 2/11/2009 12:06'!
browseImplementorsOf: aSymbol name: titleString autoSelect: autoSelectString
	"Open a implementors browser"
	self default ifNil:[^self inform: 'Cannot open ImplementorsBrowser'].
	^self default browseImplementorsOf: aSymbol name: titleString autoSelect: autoSelectString! !

!ToolSet class methodsFor: 'browsing' stamp: 'ar 7/17/2005 11:12'!
browseMessageNames: aString
	"Open a MessageNames browser"
	self default ifNil:[^self inform: 'No MessageNames present'].
	^self default browseMessageNames: aString! !

!ToolSet class methodsFor: 'browsing' stamp: 'ar 7/17/2005 11:13'!
browseMessageSet: messageList name: title autoSelect: autoSelectString
	"Open a message set browser"
	self default ifNil:[^self inform: 'Cannot open MessageSet'].
	^self default browseMessageSet: messageList name: title autoSelect: autoSelectString! !

!ToolSet class methodsFor: 'browsing' stamp: 'davidroethlisberger 2/11/2009 12:06'!
browseSendersOf: aSymbol name: titleString autoSelect: autoSelectString
	"Open a senders browser"
	self default ifNil:[^self inform: 'Cannot open SendersBrowser'].
	^self default browseSendersOf: aSymbol name: titleString autoSelect: autoSelectString! !

!ToolSet class methodsFor: 'browsing' stamp: 'ar 7/17/2005 10:54'!
browseVersionsOf: aClass selector: aSelector
	"Open a browser"
	self default ifNil:[^self inform: 'Cannot open Browser'].
	^self default browseVersionsOf: aClass selector: aSelector! !

!ToolSet class methodsFor: 'completion' stamp: 'damiencassou 7/29/2009 16:24'!
codeCompletionAround: aBlock textMorph: aTextMorph keyStroke: evt
	self default ifNil: [aBlock value. ^ self].
	self default codeCompletionAround: aBlock textMorph: aTextMorph keyStroke: evt! !

!ToolSet class methodsFor: 'debugging' stamp: 'ar 7/17/2005 10:37'!
debug: aProcess context: aContext label: aString contents: contents fullView: aBool
	"Open a debugger on the given process and context."
	self default ifNil:[
		(self confirm: 'Debugger request -- proceed?')
			ifFalse:[Processor terminateActive].
		^self].
	^self default debug: aProcess context: aContext label: aString contents: contents fullView: aBool! !

!ToolSet class methodsFor: 'debugging' stamp: 'ar 7/17/2005 10:37'!
debugContext: aContext label: aString contents: contents
	"Open a debugger on the given context."
	self default ifNil:[
		(self confirm: 'Debugger request -- proceed?')
			ifFalse:[Processor terminateActive].
		^self].
	^self default debugContext: aContext label: aString contents: contents! !

!ToolSet class methodsFor: 'debugging' stamp: 'adrian_lienhard 7/18/2009 16:03'!
debugError: anError
	"Handle an otherwise unhandled error"
	self default ifNil:[ | ctx |
		Smalltalk 
			logError: anError description 
			inContext: (ctx := anError signalerContext)
			to: 'PharoDebug.log'.
		self inform: (anError description, String cr, ctx shortStack).
		^anError return].
	^self default debugError: anError! !

!ToolSet class methodsFor: 'debugging' stamp: 'ar 9/27/2005 19:12'!
debugSyntaxError: anError
	"Handle a syntax error"
	self default ifNil:[^self debugError: anError]. "handle as usual error"
	^self default debugSyntaxError: anError! !

!ToolSet class methodsFor: 'inspecting' stamp: 'al 11/28/2005 20:32'!
explore: anObject
	"Open an explorer on the given object."
	self default ifNil:[^self inform: 'Cannot explore - no ToolSet present'].
	^self default explore: anObject! !

!ToolSet class methodsFor: 'inspecting' stamp: 'ar 7/17/2005 10:55'!
inspect: anObject
	"Open an inspector on the given object. The tool set must know which inspector type to use for which object - the object cannot possibly know what kind of inspectors the toolset provides."
	self default ifNil:[^self inform: 'Cannot inspect - no ToolSet present'].
	^self default inspect: anObject! !

!ToolSet class methodsFor: 'inspecting' stamp: 'ar 7/17/2005 10:55'!
inspect: anObject label: aString
	"Open an inspector on the given object. The tool set must know which inspector type to use for which object - the object cannot possibly know what kind of inspectors the toolset provides."
	self default ifNil:[^self inform: 'Cannot inspect - no ToolSet present'].
	^self default inspect: anObject label: aString! !

!ToolSet class methodsFor: 'inspecting' stamp: 'ar 7/17/2005 10:43'!
inspectorClassOf: anObject
	"Answer the inspector class for the given object. The tool set must know which inspector type to use for which object - the object cannot possibly know what kind of inspectors the toolset provides."
	self default ifNil:[^nil].
	^self default inspectorClassOf: anObject! !

!ToolSet class methodsFor: 'debugging' stamp: 'ar 7/17/2005 10:37'!
interrupt: aProcess label: aString
	"Open a debugger on the given process and context."
	self default ifNil:[
		(self confirm: 'Debugger request -- proceed?')
			ifFalse:[aProcess terminate].
		^self].
	^self default interrupt: aProcess label: aString! !

!ToolSet class methodsFor: 'menu' stamp: 'ar 7/17/2005 13:19'!
menuItems
	"Answer the menu items available for this tool set"
	self default ifNil:[^#()].
	^self default menuItems! !

!ToolSet class methodsFor: 'browsing' stamp: 'ar 7/17/2005 10:44'!
openChangedMessageSet: aChangeSet
	"Open a ChangedMessageSet for aChangeSet"
	self default ifNil:[^self inform: 'Cannot open MessageSet'].
	^self default openChangedMessageSet: aChangeSet! !

!ToolSet class methodsFor: 'browsing' stamp: 'ar 7/17/2005 10:44'!
openClassListBrowser: anArray title: aString
	"Open a class list browser"
	self default ifNil:[^self inform: 'Cannot open ClassListBrowser'].
	^self default openClassListBrowser: anArray title: aString! !

AppRegistry subclass: #WebBrowser
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'System-Applications'!
PrettyPrinting initialize!
